import React from 'react';
import { Link } from "react-router-dom";
import PropTypes from 'prop-types';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import IconButton from '@material-ui/core/IconButton';
import Typography from '@material-ui/core/Typography';
import { withStyles } from '@material-ui/core/styles';
import MenuIcon from '@material-ui/icons/Menu';
import HomeIcon from '@material-ui/icons/Home';

import TabBar from "./TabBar";
import MasterSearch from "./MasterSearch";

const styles = theme => ({
  root: {
    width: '100%',
  },
  grow: {
    flexGrow: 1,
  },
  menuButton: {
    marginLeft: -12,
    marginRight: 20,
  },
  homeButton: {
    display: "block",
    [theme.breakpoints.up('sm')]: {
      display: 'none',
    },
    marginRight: "16px",
    color: "white"
  },
  title: {
    display: 'none',
    [theme.breakpoints.up('sm')]: {
      display: 'block',
    },
    color: "white",
    paddingRight: "24px",
    paddingLeft: "12px",
    letterSpacing: ".02em",
    fontWeight: "400",
    fontSize: "20px"
  }
});

function Header(props) {
  const { classes } = props;
  return (
    <div className={classes.root}>
      <AppBar position="static">
        <Toolbar>
          <Link to="/" className="buttonLink">
            <IconButton
              className={classes.homeButton}
              color="secondary"
              aria-label="Open drawer"
            >
              <HomeIcon />
            </IconButton>
          </Link>
          <Link to="/" className="buttonLink">
            <Typography
              className={classes.title}
              variant="h6"
              color="inherit"
              noWrap
            >
              Niklas Luhmann-Archiv
            </Typography>
          </Link>
          <TabBar/>
          <div className={classes.grow} />
          <MasterSearch/>
        </Toolbar>
      </AppBar>
    </div>
  );
}

Header.propTypes = {
  classes: PropTypes.object.isRequired,
};

export default withStyles(styles)(Header);

/*
<div>
  <span
    style={{cursor: "pointer"}}
    onClick={switchLanguage.bind(this, 'de')}
  >
    DE
  </span>
  <br/>
  <span
    style={{cursor: "pointer"}}
    onClick={switchLanguage.bind(this, 'en')}
  >
    EN
  </span>
</div>
*/
