import React from "react";

import { Link } from "react-router-dom";

export default class ConditionalItemField extends React.Component {

  constructor(props) {
    super(props);
  }


  getValueMarkupFromValueProp(){

    const valueProp = this.props.value;
    let value = valueProp;
    let valueMarkup;

    if (!Array.isArray(valueProp)){
      value = value.trim();
    }

    if (this.props.internalLink){
      valueMarkup = <Link to={this.props.internalLink}>{value}</Link>
    } else if (this.props.link){
      valueMarkup = <a href={this.props.link}>{value}</a>
    } else if (this.props.externalLink){
      valueMarkup = <a href={this.props.externalLink} target="_blank">
        {value}
      </a>
    } else if (Array.isArray(value)){
      if (this.props.externalLinkPrefix){
        valueMarkup = value.map((val, i, arr) => {
          const link = <a
            key={"cif_extLink_" + val + i}
            href={
              this.props.externalLinkPrefix + this.props.externalLinkSuffixes[i]
            }
            target="_blank"
          >
            {val}
          </a>;
            if (i < (arr.length - 1)){
            return <span>{link}{this.props.separator || ", "}</span>;
          } else {
            return link;
          }
        });
      } else {
        valueMarkup = value.join(this.props.separator || ", ");
      }
    } else {
      valueMarkup = value;
    }

    return valueMarkup;
  }


  getValueMarkup(){
    let valueMarkup;

    if (this.props.markupType === "custom"){
      valueMarkup = this.props.children;
    } else if (this.props.markupType === "html"){
      valueMarkup = <span dangerouslySetInnerHTML={{__html: this.props.value}}/>;
    } else {
      valueMarkup = this.getValueMarkupFromValueProp();
    }

    return valueMarkup;
  }


  getLabelMarkup(){
    if (this.props.label){
      return this.props.label + ": "
    } else {
      return "";
    }
  }


  getDisplayState(){
    const valueProp = this.props.value;
    const markupType = this.props.markupType;
    let doDisplay;

    if (markupType === "custom"){
      //only if prop condition is explicitly set to false, don't display anything
      doDisplay = !(this.props.condition === false);
    } else {
      let doNotDisplay = (!valueProp)
      || valueProp === "null"
      || (Array.isArray(valueProp) && valueProp.length === 0);

      doDisplay = !doNotDisplay;
    }

    return doDisplay;
  }


  render(){

    const doDisplay = this.getDisplayState();
    if (!doDisplay){
      return "";
    }

    const labelMarkup = this.getLabelMarkup();
    const valueMarkup = this.getValueMarkup();

    return (
      <div
        title={this.props.mouseoverText}
        style={{"margin": "0", "marginBottom": "2px"}}
      >
        <span style={{
          "width": "200px",
          "display": "inline-block",
          "verticalAlign": "top"
        }}>
          {labelMarkup}
        </span>
        <span style={{
          "width": "calc(100% - 202px)",
          "display": "inline-block",
          "verticalAlign": "top"
        }}>
          {valueMarkup}
        </span>
      </div>
    );
  }
}
