import React from "react";

import { makeStyles } from '@material-ui/core/styles';

import Fab from '@material-ui/core/Fab';
import KeyboardArrowUpIcon from '@material-ui/icons/KeyboardArrowUp';

import { useScrollYPosition } from 'react-use-scroll-position';

const useStyles = makeStyles(theme => ({
  fab: {
    margin: theme.spacing(1),
    position: 'fixed',
    bottom: theme.spacing(2),
    right: theme.spacing(2),
  }
}));


// from https://stackoverflow.com/a/26808520/3890888
function scrollToY(scrollTargetY, speed, easing) {
    // scrollTargetY: the target scrollY property of the window
    // speed: time in pixels per second
    // easing: easing equation to use

    var scrollY = window.scrollY || document.documentElement.scrollTop,
        scrollTargetY = scrollTargetY || 0,
        speed = speed || 2000,
        easing = easing || 'easeOutSine',
        currentTime = 0;

    // min time .1, max time .8 seconds
    var time = Math.max(.1, Math.min(Math.abs(scrollY - scrollTargetY) / speed, .8));

    // easing equations from https://github.com/danro/easing-js/blob/master/easing.js
    var easingEquations = {
            easeOutSine: function (pos) {
                return Math.sin(pos * (Math.PI / 2));
            },
            easeInOutSine: function (pos) {
                return (-0.5 * (Math.cos(Math.PI * pos) - 1));
            },
            easeInOutQuint: function (pos) {
                if ((pos /= 0.5) < 1) {
                    return 0.5 * Math.pow(pos, 5);
                }
                return 0.5 * (Math.pow((pos - 2), 5) + 2);
            }
        };

    // add animation loop
    function tick() {
        currentTime += 1 / 60;

        var p = currentTime / time;
        var t = easingEquations[easing](p);

        if (p < 1) {
            requestAnimationFrame(tick);

            window.scrollTo(0, scrollY + ((scrollTargetY - scrollY) * t));
        } else {
            console.log('scroll done');
            window.scrollTo(0, scrollTargetY);
        }
    }

    // call it once to get started
    tick();
}


const scrollToTop = function() {
  scrollToY(0, 2000, 'easeInOutQuint');
}


export default function DocumentPageFrame(props) {
  const classes = useStyles();

  const scrollY = useScrollYPosition();

  const showScrollToTopButton = scrollY > 1100;

  return (
    <div
      className="document-page-frame editorialContent"
    >
      {
        showScrollToTopButton
        ? <Fab
            color="primary"
            aria-label="Scroll to top"
            className={classes.fab}
            onClick={scrollToTop}
          >
            <KeyboardArrowUpIcon />
          </Fab>
        : ""
      }
      <div
        className="document-page-frame-content"
      >
        {props.children}
      </div>
    </div>
  );

}
