import React from "react";

import Button from '@material-ui/core/Button';
import IconButton from '@material-ui/core/IconButton';

import TextField from '@material-ui/core/TextField';
import SendIcon from '@material-ui/icons/Send';

export default class Pagination extends React.Component {

  constructor(props){
    super(props);
    this.state = {
      textfieldValue: ""
    }
  }


  renderPageButton(number, onClick, isActive){
    return (
      <Button
        key={"sr_" + number}
        onClick={() => onClick(number)}
        color={isActive ? "primary" : null}
        variant={isActive ? "contained" : null}
      >
        {number}
      </Button>
    );
  }


  getNumberOfPages(numberOfResults, searchResultsPerPage){
    let numberOfPages;

    const numberOfFullPages = Math.floor(
      numberOfResults / searchResultsPerPage
    );

    if (numberOfResults % searchResultsPerPage !== 0){
      numberOfPages = numberOfFullPages + 1;
    } else {
      numberOfPages = numberOfFullPages;
    }

    return numberOfPages;
  }


  renderInfo(activePage, numberOfResults, searchResultsPerPage){

    const firstResultOfPage = (activePage - 1) * searchResultsPerPage + 1;
    const numberOfPages = this.getNumberOfPages(
      numberOfResults,
      searchResultsPerPage
    );

    if (activePage > numberOfPages){
      return "";
    }

    let lastResultOfPage;
    if (activePage === numberOfPages){
      lastResultOfPage = numberOfResults;
    } else {
      lastResultOfPage = firstResultOfPage + searchResultsPerPage - 1;
    }

    return (
      <span key={"sr_-1"}>
        Seite {activePage} von {numberOfPages} /
        Ergebnisse {firstResultOfPage} bis {lastResultOfPage} von {numberOfResults}
      </span>
    );
  }


  renderPages(numberOfResults, activePage, searchResultsPerPage, onChange){
    const dotsLeft = <span key={"sr_dotsLeft"} style=
      {{
        "margin": "10px"
      }}>...</span>;
    const dotsRight = <span key={"sr_dotsRight"} style=
      {{
        "margin": "10px"
      }}>...</span>;

    let markup = [];
    const renderedPages = [];
    const numberOfPages = this.getNumberOfPages(
      numberOfResults,
      searchResultsPerPage
    );

    if (activePage > numberOfPages){
      return "";
    }

    //The big loop: Let's go from the active page 3 steps in both directions
    // (left and right) and see what we'll render...
    for (
      let offsetFromActivePage = 0;
      offsetFromActivePage <= 3;
      offsetFromActivePage++
    ) {

      if (offsetFromActivePage === 0){
        markup.push(this.renderPageButton(activePage, onChange, true));
        renderedPages.push(activePage);
        continue;
      }
      if (offsetFromActivePage < 3){
        if (activePage - offsetFromActivePage > 0){
          markup = [
            this.renderPageButton(
              activePage - offsetFromActivePage, onChange, false
            ),
            ...markup
          ];
          renderedPages.push(activePage - offsetFromActivePage);
        }

        if (activePage + offsetFromActivePage <= numberOfPages){
          markup.push(
            this.renderPageButton(
              activePage + offsetFromActivePage, onChange, false
            )
          );
          renderedPages.push(activePage + offsetFromActivePage);
        }

        continue;
      }

      if (offsetFromActivePage === 3){
        if (activePage - offsetFromActivePage > 2){
          markup = [dotsLeft, ...markup];
          markup = [this.renderPageButton(2, onChange, false), ...markup];
          markup = [this.renderPageButton(1, onChange, false), ...markup];
        } else if (activePage - offsetFromActivePage === 2){
          markup = [this.renderPageButton(2, onChange, false), ...markup];
          markup = [this.renderPageButton(1, onChange, false), ...markup];
        } else if (activePage - offsetFromActivePage === 1){
          markup = [this.renderPageButton(1, onChange, false), ...markup];
        }

        //Let's check how close we are to the end
        //is the end further away than 2 pages? then render dots and last two pages
        if (activePage + offsetFromActivePage < numberOfPages - 1){
          markup.push(dotsRight);
          markup.push(
            this.renderPageButton(numberOfPages - 1, onChange, false)
          );
          markup.push(this.renderPageButton(numberOfPages, onChange, false))
        // is the end exactly two pages away?
        } else if (activePage + offsetFromActivePage === numberOfPages - 1){
          markup = [
            ...markup,
            this.renderPageButton(numberOfPages - 1, onChange, false)
          ];
          markup = [
            ...markup,
            this.renderPageButton(numberOfPages, onChange, false)
          ];
        } else if (activePage + offsetFromActivePage === numberOfPages){
          markup = [
            ...markup,
            this.renderPageButton(numberOfPages, onChange, false)
          ];
        }
      }

    }

    return markup;
  }


  render(){

    const numberOfResults = this.props.numberOfResults;
    const searchResultsPerPage = this.props.searchResultsPerPage;
    const activePage = this.props.activePage;

    const doRenderPageButtons = numberOfResults > searchResultsPerPage

    const numberOfPages = this.getNumberOfPages(
      numberOfResults,
      searchResultsPerPage
    );

    const isTextfieldValueValid = (
      (!!this.state.textfieldValue)
      && (this.state.textfieldValue >= 1)
      && (this.state.textfieldValue <= numberOfPages)
    );

    return (
      <div style={{"textAlign": "center", "wordBreak": "break-all"}}>
        {this.renderInfo(
          activePage,
          numberOfResults,
          searchResultsPerPage
        )}
        {
          doRenderPageButtons
          ? <>
            <br/>
            {this.renderPages(
              numberOfResults,
              activePage,
              searchResultsPerPage,
              this.props.onChange
            )}
            <span style={{"marginLeft": "5px", "whiteSpace": "nowrap"}}>
              <span>Gehe zu</span>
              <TextField
                value={this.state.textfieldValue}
                onChange={(e) => this.setState({
                  "textfieldValue": e.target.value
                })}
                onKeyUp={e => {
                  if ((e.keyCode === 13) && isTextfieldValueValid){
                    this.props.onChange(
                      parseInt(this.state.textfieldValue)
                    )
                  }
                }}
                type="number"
                margin="normal"
                className="pagination-manual-input"
                InputProps={{
                  inputProps: {
                    min: 1,
                    max: numberOfPages
                  }
                }}
              />
              <IconButton
                aria-label="Go"
                onClick={(e) => this.props.onChange(
                  parseInt(this.state.textfieldValue)
                )}
                color="primary"
                disabled={!isTextfieldValueValid}
              >
                <SendIcon
                  fontSize="small"
                />
              </IconButton>
            </span>
          </>
          : ""
        }
      </div>
    );
  }
}
