import React from "react";
import { Link } from "react-router-dom";
import { fetchJSON } from "../../../utils.js";

import DocumentPageFrame from "../../UI/DocumentPageFrame";
import Crumbs from "../../UI/Crumbs";
import HTMLView from "../../UI/HTMLView";

import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';

import { Route } from "react-router-dom";

import Nachlassübersicht from "./Übersicht";
import Zettelkasten from "./Zettelkasten";

const constants = require("../../../constants.js");


const TABS = [
  {
    "name": "uebersicht",
    "label": "Nachlassübersicht",
    "link": "/nachlass/uebersicht"
  },
  {
    "name": "findbuch",
    "label": "Findbuch",
    "link": "/nachlass/findbuch",
    "disabled": true
  },
  {
    "name": "zettelkasten",
    "label": "Zettelkasten",
    "link": "/nachlass/zettelkasten"
  },
  {
    "name": "manuskripte",
    "label": "Manuskripte",
    "link": "/nachlass/manuskripte",
    "disabled": true
  },
  {
    "name": "arbeitsbibliothek",
    "label": "Arbeitsbibliothek",
    "link": "/nachlass/arbeitsbibliothek",
    "disabled": true
  }
];


export default class Nachlass extends React.Component {

  constructor(props) {
    super(props);
    this.state = {};
  }


  handleMainChange(event, activeTabIndex){
    const link = TABS[activeTabIndex].link;
    this.props.history.push(link);
  }



  render(){
    const self = this;
    const activeTabName = this.props.match.params.tab;
    const activeTabIndex = TABS.findIndex(
      obj => obj.name === activeTabName
    );

    const width = this.props.width;
    const isSmallScreen = width === "xs";

      return (
        <div>
          <div className="mainSelect" style={{
            "background": "#607d8b66",
            "color": "#485e69"
          }}>
            <Tabs
              value={activeTabIndex}
              onChange={this.handleMainChange.bind(this)}
              centered={!isSmallScreen}
              variant={isSmallScreen ? "scrollable" : "standard"}
              scrollButtons={isSmallScreen ? "on" : "off"}
              indicatorColor="primary"
            >
              {
                TABS
                .map(b =>
                  <Tab
                    label={b.label}
                    disabled={b.disabled}
                    key={"b-tab-" + b.name}
                  />
                )
              }
            </Tabs>
          </div>
          <Route path="/nachlass/uebersicht"
            component={Nachlassübersicht}
          />
          <Route path="/nachlass/zettelkasten"
            component={Zettelkasten}
          />
        </div>
    );
  }
}
