import React from "react";

import { Link } from "react-router-dom";
import DocumentPageFrame from "../../UI/DocumentPageFrame";
import BusySpinner from "../../UI/BusySpinner";
import {
  fetchJSON
} from "../../../utils.js";
const uuidv4 = require('uuid/v4');

import ZKResult from "./ZKResult";

const constants = require("../../../constants.js");

import Button from '@material-ui/core/Button';

export default class Search extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      ZK: {
        results: null,
        numberOfResults: null,
        isFetching: false,
        fetchID: null
      },
      BIBL: {
        results: null,
        numberOfResults: null,
        isFetching: false,
        fetchID: null
      },
      AV: {
        results: null,
        numberOfResults: null,
        isFetching: false,
        fetchID: null
      }
    }
  }


  getURLState(url){
    if (typeof url !== "string"){
      url = this.props.location.search;
    }

    //https://gitlab.ub.uni-bielefeld.de/luhmann/luhmann-react/issues/334
    //Sometimes the url has %20 chars, sometimes the spaces are unescaped.
    //I have not found out why yet, but this solves the problem:
    url = decodeURIComponent(url);

    let searchString =
      url && url.substring(0, 3) === "?q="
      ? url.substring(3)
      : "";

    searchString = searchString.trim();

    return searchString;
  }


  componentDidMount() {
    this.fetchData();
    document.title = "Suche" + " - " + constants.APP_TITLE;
  }


  componentWillUnmount(){
    if (document) {
      document.title = constants.APP_TITLE;
    }
  }


  fetchData(){
    this.fetchZK();
    this.fetchBIBL();
    this.fetchAV();
  }


  fetchZK(){
    const self = this;
    const searchString = this.getURLState();

    const ZKQuery = {
      "fulltext": searchString,
      "rows": 5,
      "fuzzy": true
    };

    const zk_url = constants.URLS.DATABASE_API
    + `ZK/search`
    + "?q=" + encodeURI(JSON.stringify(ZKQuery))
    + "&client_id=" + constants.CLIENT_ID;

    const fetchID = uuidv4();

    this.setState({
      ZK: {
        results: null,
        numberOfResults: null,
        isFetching: true,
        fetchID
      }
    });

    fetchJSON(zk_url).then(function(json) {
      if (self.state.ZK.fetchID === fetchID){
        self.setState({
          ZK: {
            results: json.results,
            numberOfResults: json.numberOfResults,
            isFetching: false
          }
        });
      }
    })
    .catch(e => console.log(e));
  }


  fetchBIBL(){
    const self = this;
    const searchString = this.getURLState();

    const BIBLQuery = {
      "fulltext": searchString,
      "rows": 5,
      "types": [
        "book",
        "bookSection",
        "journalArticle",
        "newspaperArticle"
      ]
    };

    const BIBL_url = constants.URLS.DATABASE_API
    + `BIBL/search`
    + "?q=" + encodeURI(JSON.stringify(BIBLQuery))
    + "&client_id=" + constants.CLIENT_ID;

    const fetchID = uuidv4();

    this.setState({
      BIBL: {
        results: null,
        numberOfResults: null,
        isFetching: true,
        fetchID
      }
    });

    fetchJSON(BIBL_url).then(function(json) {
      if (self.state.BIBL.fetchID === fetchID){
        self.setState({
          BIBL: {
            results: json.results,
            numberOfResults: json.numberOfResults,
            isFetching: false
          }
        });
      }
    })
    .catch(e => console.log(e));
  }


  fetchAV(){
    const self = this;
    const searchString = this.getURLState();

    const AVQuery = {
      "fulltext": searchString,
      "rows": 5
    };

    const AV_url = constants.URLS.DATABASE_API
    + `AV/search`
    + "?q=" + encodeURI(JSON.stringify(AVQuery))
    + "&client_id=" + constants.CLIENT_ID;

    const fetchID = uuidv4();

    this.setState({
      AV: {
        results: null,
        numberOfResults: null,
        isFetching: true,
        fetchID
      }
    });

    fetchJSON(AV_url).then(function(json) {
      if (self.state.AV.fetchID === fetchID){
        self.setState({
          AV: {
            results: json.results,
            numberOfResults: json.numberOfResults,
            isFetching: false
          }
        });
      }
    })
    .catch(e => console.log(e));
  }


  componentDidUpdate(previousProps, previousState){
    const currentQuery = this.getURLState();
    const oldSearch = previousProps.location.search;
    const oldQuery = this.getURLState(oldSearch);

    if (oldQuery !== currentQuery){
      this.fetchData();
    }
  }


  render(){
    const searchString = this.getURLState();

    return (
      <DocumentPageFrame>
        <h1>Suche nach {searchString}</h1>
        <h2>Zettelkasten</h2>
        {
          this.state.ZK.results
          ? <>
            {
              this.state.ZK.results.map((r, i) => {
                return <ZKResult result={r} key={"ZKResult_" + r.ekin}/>
              })
            }
            {
              this.state.ZK.results.length > 0
              ? <>
                <br/>
                <Button
                  variant="contained"
                  color="primary"
                  onClick={() => {
                    this.props.history.push({
                      "pathname": "/bestand/zettelkasten/suche",
                      "search": `q={"fulltext": "${searchString}", "fuzzy": true}`
                    });
                  }}
                >
                  Alle {this.state.ZK.numberOfResults} Ergebnisse anzeigen
                </Button>
              </>
              : "Keine Ergebnisse gefunden."
            }
          </>
          : <BusySpinner/>
        }
        <h2>Bibliographie</h2>
        {
          this.state.BIBL.results
          ? <>
            {
              this.state.BIBL.results.map((r, i) => {
                return <p key={"BIBL_r_" + i}>
                  <Link to={"/bestand/bibliographie/item/" + r.id}>
                    {r.displayTitle}
                  </Link>
                </p>;
              })
            }
            {
              this.state.BIBL.results.length > 0
              ? <Button
                variant="contained"
                color="primary"
                onClick={() => {
                  this.props.history.push({
                    "pathname": "/bestand/register/bibliographie",
                    "search": `q={"fulltext": "${searchString}", "fuzzy": true}`
                  });
                }}
              >
                Alle {this.state.BIBL.numberOfResults} Ergebnisse anzeigen
              </Button>
              : "Keine Ergebnisse gefunden."
            }
          </>
          : <BusySpinner/>
        }

        <h2>Audio/Video</h2>
        {
          this.state.AV.results
          ? <>
            {
              this.state.AV.results.map((r, i) => {
                return <p key={"AV_r_" + i}>
                  <Link to={"/bestand/av/item/" + r.id}>
                    {r.title}
                  </Link>
                </p>;
              })
            }
            {
              this.state.AV.results.length > 0
              ? <Button
                variant="contained"
                color="primary"
                onClick={() => {
                  this.props.history.push({
                    "pathname": "/bestand/av/suche",
                    "search": `q={"fulltext": "${searchString}", "fuzzy": true}`
                  });
                }}
              >
                Alle {this.state.AV.numberOfResults} Ergebnisse anzeigen
              </Button>
              : "Keine Ergebnisse gefunden."
            }
          </>
          : <BusySpinner/>
        }
      </DocumentPageFrame>
    );
  }
}
