import React from "react";
import { Link } from "react-router-dom";

import TilesContentFrame from "../UI/TilesContentFrame";
import PortalCard from "../UI/PortalCard";
import Button from '@material-ui/core/Button';
import Grid from '@material-ui/core/Grid';
import Tooltip from '@material-ui/core/Tooltip';

export default class Start extends React.Component {
  render(){
    return (
        <TilesContentFrame>
          <Grid container spacing={2}>
            <PortalCard
              link="/person"
              id="person_theorie"
              title="Person und Theorie"
              image="/assets/images/card_backgrounds/pixel_portrait.jpg"
              description="Niklas Luhmann (1927-1998) ist einer der bedeutendsten Soziologen des 20. Jahrhunderts. In einer fast vierzigjährigen Forschungs- und Publikationstätigkeit hat er eine umfassende Sozial- und Gesellschaftstheorie entwickelt, die hinsichtlich ihrer Begriffsarchitektur, ihres Universalitätsanspruchs und ihrer interdisziplinären Anschlussfähigkeit einzigartig ist. Erfahren Sie hier mehr zu seiner Person, zur Theorie und den Publikationen."
            >
              <Link className="buttonLink" to="/person/person-und-werk">
                <Button size="small" color="primary">
                  Person und Werk
                </Button>
              </Link>
              <Link className="buttonLink" to="/person/werkverzeichnis">
                <Button size="small" color="primary">
                  Werkverzeichnis
                </Button>
              </Link>
            </PortalCard>


            <PortalCard
              link="/bestand"
              id="bestand"
              title="Online-Bestand"
              image='/assets/images/card_backgrounds/zettelkasten.jpg'
              description="In den Online-Datenbanken können Sie den transkribierten und edierten Zettelkasten einsehen sowie Faksimiles der Manuskripte aus dem Nachlass lesen, in den Bestandsregistern des Projekts (Bibliographie, Personen- und Sachregister) und der Gesamtbibliographie Luhmanns recherchieren sowie Video- und Audiodokumente mit Luhmannschen Vorlesungen, Vorträgen und Interviews abrufen. (Datenbestände im Aufbau)"
            >
              <Link className="buttonLink" to="/bestand/zettelkasten/tutorial">
                <Button size="small" color="primary">
                  Zettelkasten
                </Button>
              </Link>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled title="noch nicht verfügbar" size="small" color="primary">
                    Manuskripte
                  </Button>
                </span>{/* Wrapped in <span> as recommended in https://material-ui.com/demos/tooltips/#disabled-elements */}
              </Tooltip>
              <Link className="buttonLink" to="/bestand/av/suche">
                <Button size="small" color="primary">
                  Audio/Video
                </Button>
              </Link>
              <Link className="buttonLink" to='/bestand/register'>
                <Button size="small" color="primary">
                  Bestandsregister
                </Button>
              </Link>
              <Link className="buttonLink" to='/bestand/nl-gesamtbibliographie'>
                <Button size="small" color="primary">
                  NL-Bibliographie
                </Button>
              </Link>
            </PortalCard>

            <PortalCard
              link="/nachlass"
              id="nachlass"
              title="Über den Nachlass"
              image="/assets/images/card_backgrounds/zettel.jpg"
              description="Der wissenschaftliche Nachlass Niklas Luhmanns besteht insbesondere aus seinem ca. 90.000 Dokumente umfassenden Zettelkasten und über 150 zu Lebzeiten unveröffentlichten Manuskripten und den Vorfassungen bereits publizierter Werke. Weitere Bestandteile sind seine Bibliothek sowie die Korrespondenz. Hier finden Sie Erläuterungen und Übersichten zu den verschiedenen Nachlassbeständen. (Datenbestände im Aufbau)"
            >
              <Link className="buttonLink" to='/nachlass/uebersicht'>
                <Button size="small" color="primary">
                  Nachlassübersicht
                </Button>
              </Link>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled title="noch nicht verfügbar" size="small" color="primary">
                    Findbuch
                  </Button>
                </span>{/* Wrapped in <span> as recommended in https://material-ui.com/demos/tooltips/#disabled-elements */}
              </Tooltip>
              <Link className="buttonLink" to='/nachlass/zettelkasten'>
                <Button size="small" color="primary">
                  Zettelkasten
                </Button>
              </Link>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Manuskripte
                  </Button>
                </span>{/* Wrapped in <span> as recommended in https://material-ui.com/demos/tooltips/#disabled-elements */}
              </Tooltip>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Arbeitsbibliothek
                  </Button>
                </span>
              </Tooltip>
            </PortalCard>

            <PortalCard
              link="/projekt/beschreibung"
              id="projekt"
              title="Über das Projekt"
              image="/assets/images/card_backgrounds/Eingangshof.jpg"
              description="Dieses Portal entsteht im Rahmen des von der Akademie der Wissenschaften und der Künste NRW geförderten Langzeitforschungsprojekts „Niklas Luhmann - Theorie als Passion.  Wissenschaftliche Erschließung und Edition des Nachlasses“ (2015-2030), in dem die Fakultät für Soziologie, das Archiv und die Bibliothek der Universität Bielefeld mit dem Cologne Center for eHumanities der Universität zu Köln kooperieren."
            >
              <Link className="buttonLink" to='/projekt/beschreibung'>
                <Button size="small" color="primary">
                  Projektbeschreibung
                </Button>
              </Link>
              <Link className="buttonLink" to='/projekt/publikationen'>
                <Button size="small" color="primary">
                  Publikationen
                </Button>
              </Link>
              <Link className="buttonLink" to='/projekt/vortraege-interviews'>
                <Button size="small" color="primary">
                  Vorträge/Interviews
                </Button>
              </Link>
              <Link className="buttonLink" to='/projekt/dokumentation'>
                <Button size="small" color="primary">
                  Dokumentation
                </Button>
              </Link>
              <Link className="buttonLink" to='/projekt/team'>
                <Button size="small" color="primary">
                  Team
                </Button>
              </Link>
            </PortalCard>
          </Grid>
        </TilesContentFrame>
    );
  }
}
