import React from "react";
import { Link } from "react-router-dom";
import { fetchJSON } from "../../../../utils.js";

import DocumentPageFrame from "../../../UI/DocumentPageFrame";
import Crumbs from "../../../UI/Crumbs";

import ConditionalItemField from "../../../UI/ConditionalItemField"

import Button from '@material-ui/core/Button';

import FormControl from '@material-ui/core/FormControl';
import Select from '@material-ui/core/Select';
import InputLabel from '@material-ui/core/InputLabel';
import MenuItem from '@material-ui/core/MenuItem';

const constants = require("../../../../constants.js");

export default class MediaItem extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      playbackRate: 1
    };
  }


  renderSpeedSelect(partIndex){
    return <FormControl>
      <InputLabel htmlFor={"speed-select-" + partIndex}>
        Abspielgeschwindigkeit
      </InputLabel>
      <Select
        value={
          this.refs["mediaElement-" + partIndex]
          && this.refs["mediaElement-" + partIndex].playbackRate.toString()
          || 1
        }
        onChange={(e) => {
          const newValue = parseFloat(e.target.value);
          this.setState({
            playbackRate: newValue
          });
          this.refs["mediaElement-" + partIndex].playbackRate = newValue;
        }}
        inputProps={{
          name: 'speed-select-' + partIndex,
          id: 'speed-select-' + partIndex,
        }}
      >
        <MenuItem value={"0.5"}>0.5x</MenuItem>
        <MenuItem value={"0.75"}>0.75x</MenuItem>
        <MenuItem value={"1"}>1x</MenuItem>
        <MenuItem value={"1.25"}>1.25x</MenuItem>
        <MenuItem value={"1.5"}>1.5x</MenuItem>
        <MenuItem value={"1.75"}>1.75x</MenuItem>
      </Select>
    </FormControl>
  }


  render(){

    const type = this.props.type;
    const partIndex = this.props.partIndex;
    const files = this.props.files;

    if (type === "video"){
      return <div
        className="video_container"
      >
        <video
          controls={true}
          ref={"mediaElement-" + partIndex}
          id={"mediaElement-" + partIndex}
        >
          {
            files.map(file => {
              return <source
                src={constants.URLS.AV_ASSET_FOLDER + file.name}
                type={file.mimeType}
                key={file.name + "-" + file.mimeType}
              />;
            })
          }
        </video>
        <div style={{"marginTop": "10px"}}>
          {this.renderSpeedSelect(partIndex)}
        </div>
      </div>;
  } else {
    return <div
      className="audio_container"
    >
      <audio
        style={{
          "width": "calc(100% - 100px)",
          "marginRight": "20px"
        }}
        controls={true}
        ref={"mediaElement-" + partIndex}
        id={"mediaElement-" + partIndex}
      >
        {
          files.map(file => {
            return <source
              src={constants.URLS.AV_ASSET_FOLDER + file.name}
              type={file.mimeType}
              key={file.name + "-" + file.mimeType}
            />;
          })
        }
      </audio>
        {this.renderSpeedSelect(partIndex)}
      </div>;
    }
  }

}
