import React from "react";

import { Link } from "react-router-dom";
import { fetchJSON } from "../../../utils.js";
const uuidv4 = require('uuid/v4');

//Shared UI
import FullPageFrame from "../../UI/FullPageFrame";
import BusySpinner from "../../UI/BusySpinner";
import Crumbs from "../../UI/Crumbs";
import Pagination from "../../UI/Pagination";

//Material-UI
import { withStyles } from '@material-ui/core/styles';
import AppBar from '@material-ui/core/AppBar';
import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';
import Typography from '@material-ui/core/Typography';
import TextField from '@material-ui/core/TextField';
import Grid from '@material-ui/core/Grid';
import Paper from '@material-ui/core/Paper';
import AccountCircle from '@material-ui/icons/AccountCircle';
import FormControlLabel from '@material-ui/core/FormControlLabel';
import Switch from '@material-ui/core/Switch';
import withWidth from '@material-ui/core/withWidth';

const constants = require("../../../constants.js");

import { Route } from "react-router-dom";

import Zettelkasten from "./ZK"
import Register from "./Register"
import AVSearch from "./AV/Search"

function TabContainer(props) {
  return (
    <Typography component="div" style={{ padding: 8 * 3 }}>
      {props.children}
    </Typography>
  );
}

const BESTÄNDE = [
  {
    "name": "zettelkasten",
    "label": "Zettelkasten",
    "link": "/bestand/zettelkasten/suche"
  },
  {
    "name": "manuskripte",
    "label": "Manuskripte",
    "link": "",
    "disabled": true
  },
  {
    "name": "av",
    "label": "Audio/Video",
    "link": "/bestand/av/suche"
  },
  {
    "name": "register",
    "label": "Bestandsregister",
    "link": "/bestand/register/bibliographie"
  },
];


class BestandPanel extends React.Component {

  constructor(props) {
    super(props);
  }


  handleMainChange(event, activeBestandsIndex){
    const link = BESTÄNDE[activeBestandsIndex].link;
    this.props.history.push(link);
  }


  render(){
    const self = this;
    const activeBestandName = this.props.match.params.bestand;
    const activeBestandsIndex = BESTÄNDE.findIndex(
      obj => obj.name === activeBestandName
    );

    const width = this.props.width;
    const isSmallScreen = width === "xs";

    return (
      <div>
        <div className="mainSelect" style={{
          "background": "#607d8b66",
          "color": "#485e69"
        }}>
          <Tabs
            value={activeBestandsIndex}
            onChange={this.handleMainChange.bind(this)}
            centered={!isSmallScreen}
            variant={isSmallScreen ? "scrollable" : "standard"}
            scrollButtons={isSmallScreen ? "on" : "off"}
            indicatorColor="primary"
          >
            {
              BESTÄNDE
              .map(b =>
                <Tab
                  label={b.label}
                  disabled={b.disabled}
                  key={"b-tab-" + b.name}
                />
              )
            }
          </Tabs>
        </div>
        <Route path="/bestand/zettelkasten/:subpage"
          component={Zettelkasten}
        />
        <Route exact path="/bestand/av/suche"
          component={AVSearch}
        />
        <Route path="/bestand/register/:subpage"
          component={Register}
        />
      </div>
    );
  }
}

export default withWidth()(BestandPanel);
