import React from "react";

import { Link } from "react-router-dom";

import LetterFilter from "../../../../../UI/SearchFilters/LetterFilter/";
import TextFilter from "../../../../../UI/SearchFilters/TextFilter";
import YearFilter from "../../../../../UI/SearchFilters/YearFilter";
import OptionsSelect from "../../../../../UI/SearchFilters/OptionsSelect";

import ExpansionPanel from '@material-ui/core/ExpansionPanel';
import ExpansionPanelSummary from '@material-ui/core/ExpansionPanelSummary';
import ExpansionPanelDetails from '@material-ui/core/ExpansionPanelDetails';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import Button from '@material-ui/core/Button';
import Icon from '@material-ui/core/Icon';
import IconButton from '@material-ui/core/IconButton';
import ClearIcon from '@material-ui/icons/Clear';

import * as BiblLogic from "../../../../../../BiblLogic.js";
const constants = require("../../../../../../constants.js");

export default class Filters extends React.Component {

  constructor(props) {
    super(props);
  }


  handleFilterChange(key, newValue){
    this.props.onChange(key, newValue);
  }


  render(){
    const self = this;
    const state = this.props.state;

    return (
        <div
          className="filters"
          style={{
            "gridGap": "20px"
          }}
        >

          <div style={{"display": "flex", "justifyContent": "space-between"}}>
            <h2 style={{"margin": "0"}}>Suchfilter</h2>
            <Link
              className="buttonLink"
              to="/bestand/register/bibliographie"
              title="Alle Filter zurücksetzen"
            >
              <IconButton color="primary" aria-label="Alle Filter zurücksetzen">
                <ClearIcon />
              </IconButton>
            </Link>
          </div>

          <div
            style={{"gridArea": "1 / 1 / 2 / 2"}}
            className="filter"
          >
            <TextFilter
              id="fulltext"
              value={state.fulltext}
              onChange={value => this.handleFilterChange(
                "fulltext", value
              )}
              label="Suche in allen Feldern"
            />
            <TextFilter
              id="author"
              value={state.author}
              onChange={value => this.handleFilterChange(
                "author", value
              )}
              label="Autor/Herausgeber"
            />
            <TextFilter
              id="title"
              value={state.title}
              onChange={value => this.handleFilterChange(
                "title", value
              )}
              label="Titel"
            />
          </div>
          <YearFilter
            onChange={(date) => this.handleFilterChange(
              "date", date
            )}
            gridArea="1 / 4 / 2 / 5"
            value={state.date}
          />
          <hr/>
          <ExpansionPanel>
            <ExpansionPanelSummary expandIcon={<ExpandMoreIcon />}>
              Publikations-/Medientyp
            </ExpansionPanelSummary>
            <ExpansionPanelDetails>
              <OptionsSelect
                id="biblTypes"
                options={BiblLogic.bibl_types.map(t => {
                  return {
                    id: t.name,
                    label: t.title
                  }
                })}
                onChange={(selectedTypes) => this.handleFilterChange(
                  "types", selectedTypes
                )}
                selected={state.types}
                gridArea="1 / 2 / 2 / 3"
              />
            </ExpansionPanelDetails>
          </ExpansionPanel>
          <hr/>
          <ExpansionPanel>
            <ExpansionPanelSummary expandIcon={<ExpandMoreIcon />}>
              Publikationssprache
            </ExpansionPanelSummary>
            <ExpansionPanelDetails>
              <OptionsSelect
                id="languages"
                options={BiblLogic.languages.map(l => {
                  return {
                    id: l.value,
                    label: l.title
                  }
                })}
                onChange={(selectedTypes) => this.handleFilterChange(
                  "languages", selectedTypes
                )}
                selected={state.languages}
                gridArea="1 / 4 / 2 / 5"
              />
            </ExpansionPanelDetails>
          </ExpansionPanel>
          <hr/>
          <LetterFilter
            onChange={(selectedLetters) => this.handleFilterChange(
              "letters", selectedLetters
            )}
            selected={state.letters}
            gridArea="1 / 3 / 2 / 4"
            setOnlyOneActiveLetter={true}
            label="Alphabetische Filterung"
          />
          <hr/>
          <Link
            className="buttonLink"
            to="/bestand/register/bibliographie"
          >
            <Button
              color="primary"
            >
              Alle Filter zurücksetzen
            </Button>
          </Link>
        </div>
    );
  }
}
