import React from "react";

import { Link } from "react-router-dom";

import DocumentPageFrame from "../../../UI/DocumentPageFrame";
import BestandBar from "../../../UI/BestandBar";
import FullPageFrame from "../../../UI/FullPageFrame";

const constants = require("../../../../constants.js");

import { Route } from "react-router-dom";

import BibliographieSuche from "./Bibliographie/Search";
import Tutorial from "./Tutorial";

import Button from '@material-ui/core/Button';
import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';
import Typography from '@material-ui/core/Typography';
import withWidth from '@material-ui/core/withWidth';

function TabContainer(props) {
  return (
    <Typography component="div" style={{ padding: 8 * 3 }}>
      {props.children}
    </Typography>
  );
}

const SUBPAGES = [
  {
    "name": "bibliographie",
    "label": "Bestandsbibliographie",
    "link": "/bestand/register/bibliographie"
  },
  {
    "name": "schlagwortregister",
    "label": "Schlagwortregister",
    "link": "/bestand/register/schlagwortregister",
    "disabled": true
  },
  {
    "name": "personenregister",
    "label": "Personenregister",
    "link": "/bestand/register/personenregister",
    "disabled": true
  },
  {
    "name": "tutorial",
    "label": "Tutorial",
    "link": "/bestand/register/tutorial"
  }
];


class Register extends React.Component {

  constructor(props) {
    super(props);
  }


  handleSubpageChange(activeSubpageIndex){
    const subpageURL = SUBPAGES[activeSubpageIndex].link;
    const location = {...this.props.history.location};
    location.pathname = subpageURL;
    this.props.history.push(location);
  }


  render(){
    const subpageName = this.props.match.params.subpage;
    const activeSubpageIndex = SUBPAGES.findIndex(
      obj => obj.name === subpageName
    );

    const width = this.props.width;
    const isSmallScreen = width === "xs";

    return (
      <FullPageFrame>
        <BestandBar>
          <Tabs
            value={activeSubpageIndex}
            onChange={(e, activeSubpageIndex) => this.handleSubpageChange(
              activeSubpageIndex
            )}
            indicatorColor="primary"
            textColor="primary"
            centered={!isSmallScreen}
            variant={isSmallScreen ? "scrollable" : "standard"}
            scrollButtons={isSmallScreen ? "on" : "off"}
          >
            {
              SUBPAGES.map((item, i) => {
                return <Tab
                  key={"register-subpage-" + i + "-" + item.label}
                  label={item.label}
                  disabled={item.disabled}
                />;
              })
            }
          </Tabs>
        </BestandBar>

        <Route path="/bestand/register/bibliographie"
          exact
          component={BibliographieSuche}
        />
        <Route path="/bestand/register/tutorial"
          exact
          component={Tutorial}
        />
      </FullPageFrame>
    );
  }
}

export default withWidth()(Register);
