import React from "react";
import { Link } from "react-router-dom";

import TilesContentFrame from "../../UI/TilesContentFrame";
import PortalCard from "../../UI/PortalCard";
import Button from '@material-ui/core/Button';
import Grid from '@material-ui/core/Grid';
import Tooltip from '@material-ui/core/Tooltip';

const constants = require("../../../constants.js");

export default class TilesOverview extends React.Component {

  componentDidMount(){
    document.title = "Bestand"
    + " - " + constants.APP_TITLE;
  }


  componentWillUnmount(){
    if (document) {
      document.title = constants.APP_TITLE;
    }
  }


  render(){
    return (
        <TilesContentFrame>
          <Grid container spacing={2}>
            <PortalCard
              link="/bestand/zettelkasten/tutorial"
              id="zettelkasten"
              title="Zettelkasten"
              image="/assets/images/card_backgrounds/zettelkasten.jpg"
              description="Luhmanns zentrales Arbeits- und Denkwerkzeug war ein Zettelkasten, den er über 40 Jahre lang gepflegt hat und der schließlich ca. 90.000 Zettel umfasste. Er besteht aus zwei weitgehend getrennten Sammlungen: Zettelkasten I (ca. 1952-1963) mit 7 Auszüge und Zettelkasten II (ca. 1963-1997) mit 20 Auszügen. Diese Sammlungen sind hier in einer digitalisierten und edierten Version einsehbar. Dabei stehen verschiedene Einstiegsinstrumente (Übersichten, Register) sowie eine Volltextsuche zur Verfügung. (Datenbestände im Aufbau)"
            >
              <Link className="buttonLink" to="/bestand/zettelkasten/suche">
                <Button size="small" color="primary">
                  Zettelsuche
                </Button>
              </Link>
              <Link
                className="buttonLink"
                to="/bestand/zettelkasten/inhaltsuebersicht"
              >
                <Button size="small" color="primary">
                  Inhaltsübersicht
                </Button>
              </Link>
              <Link
                className="buttonLink"
                to="/bestand/zettelkasten/auszuege"
              >
                <Button size="small" color="primary">
                  Auszugsübersicht
                </Button>
              </Link>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Schlagwortregister
                  </Button>
                </span>
              </Tooltip>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Personenregister
                  </Button>
                </span>
              </Tooltip>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Bibliographie
                  </Button>
                </span>
              </Tooltip>
              <Link
                className="buttonLink"
                to="/bestand/zettelkasten/tutorial"
              >
                <Button size="small" color="primary">
                  Tutorial
                </Button>
              </Link>
            </PortalCard>
            <PortalCard
              link="/bestand/manuskripte"
              id="manuskripte"
              title="Manuskripte/Typoskripte"
              image="/assets/images/card_backgrounds/manuskript.jpg"
              description="Luhmanns Nachlass enthält eine große Zahl von Manuskripten, die meistenteils als maschinenschriftliche Typoskripte oder als Ausdrucke von Computerdateien vorliegen. Zum einen handelt es sich um bislang unpublizierte Monographien und Aufsätze sowie Vorlesungs- und Vortragsskripte aus den 1960er bis 1990er Jahren, zum anderen um Vorfassungen bereits veröffentlichter Werke. Die Texte werden hier als digitalisierte Faksimiles zugänglich gemacht. (Seite im Aufbau)"
            >
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Monographien
                  </Button>
                </span>
              </Tooltip>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Aufsätze
                  </Button>
                </span>
              </Tooltip>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Vorlesungen
                  </Button>
                </span>
              </Tooltip>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Vorträge
                  </Button>
                </span>
              </Tooltip>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Tutorial
                  </Button>
                </span>
              </Tooltip>
            </PortalCard>
            <PortalCard
              link="/bestand/av/suche"
              id="av"
              title="Audio/Video"
              image="/assets/images/card_backgrounds/av.jpg"
              description="Luhmanns umfassende Lehr- und Vortragstätigkeit wurden seit den 1980er Jahren häufiger auf Audio- oder Videomitschnitten dokumentiert; außerdem existieren einige Interviewaufzeichnungen. Diese Aufnahmen sind hier abrufbar. (Datenbestände im Aufbau)"
            >
              <Link className="buttonLink" to="/bestand/av/suche">
                <Button size="small" color="primary">
                  Alle Dokumente
                </Button>
              </Link>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Vorlesungen
                  </Button>
                </span>
              </Tooltip>
              <Link className="buttonLink" to={encodeURI("/bestand/av/suche?q={\"types\":[\"Vortrag\"]}")}>
                <Button size="small" color="primary">
                  Vorträge
                </Button>
              </Link>
              <Link className="buttonLink" to={encodeURI("/bestand/av/suche?q={\"types\":[\"Interview\"]}")}>
                <Button size="small" color="primary">
                  Interviews
                </Button>
              </Link>
            </PortalCard>
            <PortalCard
              link="/bestand/register"
              id="register"
              title="Bestandsregister"
              image="/assets/images/card_backgrounds/buecherregal.jpg"
              description="Das Bestandsregister bietet einen Zugang zu allen Materialien des Forschungsportals. Zur Zeit kann auf die durchsuchbare Datenbank zugegriffen werden, die alle Literaturangaben aufführt, die im Portalbestand erwähnt werden. Mittelfristig wird das Bestandsregister durch ein Schlagwort- und ein Personenregister ergänzt. (Datenbestände im Aufbau)"
            >
              <Link className="buttonLink" to="/bestand/register/bibliographie">
                <Button size="small" color="primary">
                  Bestandsbibliographie
                </Button>
              </Link>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Schlagwortregister
                  </Button>
                </span>
              </Tooltip>
              <Tooltip className="buttonLink" title="noch nicht verfügbar">
                <span>
                  <Button disabled size="small" color="primary">
                    Personenregister
                  </Button>
                </span>
              </Tooltip>
              <Link className="buttonLink" to="/bestand/register/tutorial">
                <Button size="small" color="primary">
                  Tutorial
                </Button>
              </Link>
            </PortalCard>
          </Grid>
        </TilesContentFrame>
    );
  }
}
