import React from "react";

import { Link } from "react-router-dom";
import { fetchJSON } from "../../../../utils.js";
import qs from 'query-string';

import DocumentPageFrame from "../../../UI/DocumentPageFrame";
import Crumbs from "../../../UI/Crumbs";
import BusySpinner from "../../../UI/BusySpinner";
import Pagination from "../../../UI/Pagination";

const constants = require("../../../../constants.js");

export default class Auszug extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      results: null
    };
  }


  getURLState(){
    const url = this.props.location.search;
    const zk_nummer = parseInt(this.props.match.params.zk_nummer) || 1;
    const auszug = parseInt(this.props.match.params.auszug) || 1;
    const page = parseInt(qs.parse(url).page) || 1;

    return {
      zk_nummer,
      auszug,
      page
    }
  }


  componentDidMount() {
    this.fetchData();
    return;
  }


  componentDidUpdate(previousProps, previousState){
    const urlState = this.getURLState();
    const oldZKNummer = parseInt(previousProps.match.params.zk_nummer) || 1;
    const oldAuszug = parseInt(previousProps.match.params.auszug) || 1;
    const oldPage = parseInt(qs.parse(previousProps.location.search).page) || 1;

    if (
      (oldZKNummer !== urlState.zk_nummer)
      || (oldAuszug !== urlState.auszug)
      || (oldPage !== urlState.page)
    ){
      this.fetchData();
    }
  }


  fetchData(){

    const self = this;
    const urlState = this.getURLState();
    const zk_nummer = urlState.zk_nummer;
    const auszug = urlState.auszug;
    const page = urlState.page;
    const auszugAsString = auszug.toString();
    const auszugPadded = auszugAsString.padStart(2, "0");

    const url = constants.URLS.DATABASE_API
    + "ZK/" + zk_nummer
    + "/auszug/" + auszugPadded
    + "?page=" + page;

    this.setState({
      isFetching: true,
      results: null,
      numberOfResults: null
    });

    fetchJSON(url).then(function(json) {
      self.setState({
        results: json.results,
        numberOfResults: json.numberOfResults,
        isFetching: false,
        firstResult: json.firstResult,
        lastResult: json.lastResult
      });
    })
    .catch(e => console.log(e));

    return;

  }


  setPage(activePageNumber){
    const location = {...this.props.history.location};
    location.search = "page=" + activePageNumber;
    this.props.history.push(location);
  }


  renderResults(results) {
    return results.map((scan, i) => {
      return <li key={i}>
        <Link to={"/bestand/zettelkasten/zettel/" + scan["ekin"]}>
          {scan.title || "Unbenannter Zettel (" + scan.ekin + ")"}
        </Link>
      </li>;
    });
  }


  render(){

    const self = this;
    let resultsMarkup;
    const urlState = this.getURLState();
    const zk_nummer = urlState.zk_nummer;
    const auszug = urlState.auszug;
    const activePage = urlState.page;

    if (!self.state.results || self.state.isFetching){
      resultsMarkup = <BusySpinner/>;
    } else {
      resultsMarkup = <div>
        <Pagination
          numberOfResults={this.state.numberOfResults}
          activePage={activePage}
          onChange={(i) => this.setPage(i)}
          searchResultsPerPage={constants.ZETTEL_PER_AUSZUG_PAGE}
        />
        <div>
          <ul>
            {self.renderResults(self.state.results)}
          </ul>
        </div>
        <Pagination
          numberOfResults={this.state.numberOfResults}
          activePage={activePage}
          onChange={(i) => this.setPage(i)}
          searchResultsPerPage={constants.ZETTEL_PER_AUSZUG_PAGE}
        />
      </div>;
    }

    const zk_number_roman = (zk_nummer == 1) ? "I" : "II";

    return (
      <DocumentPageFrame>
        <Crumbs crumbs={[
          {
            "link": "/",
            "title": "Niklas-Luhmann-Archiv"
          },
          {
            "link": "/bestand",
            "title": "Bestand"
          },
          {
            "link": "/bestand/zettelkasten",
            "title": "Zettelkasten"
          },
          {
            "link": "/bestand/zettelkasten/auszuege#ZK" + zk_nummer,
            "title": "Zettelkasten " + zk_number_roman
          },
          {
            "link": "/bestand/zettelkasten/" + zk_nummer
            + "/auszug/" + auszug,
            "title": "Auszug " + auszug
          }
        ]} />
        <h1 className="with-subtitle">
          Auszug {auszug}
        </h1>
        {
          this.state.firstResult ?
          <h2 className="subtitle">
            {
              (
                this.state.firstResult.title
                || "Unbenannter Zettel (" + this.state.firstResult.ekin + ")"
              )
              + " - "
              + (
                this.state.lastResult.title
                || "Unbenannter Zettel (" + this.state.lastResult.ekin + ")"
              )
            }
          </h2>
          : ""
        }
        {resultsMarkup}
      </DocumentPageFrame>
    );
  }
}
