import React from "react";

import { Link } from "react-router-dom";
import { fetchJSON } from "../../../../utils.js";

import DocumentPageFrame from "../../../UI/DocumentPageFrame";
import Crumbs from "../../../UI/Crumbs";
import BusySpinner from "../../../UI/BusySpinner";
import HTMLView from "../../../UI/HTMLView";

import {getPublicationDate} from "./logic.js";

const constants = require("../../../../constants.js");

export default class Auszüge extends React.Component {

  constructor(props) {
    super(props);
    this.state = {};
  }


  componentDidMount() {
    const self = this;

    const url = constants.URLS.DATABASE_API + "ZK/auszuege";

    fetchJSON(url).then(function(json) {
      self.setState({
        auszuege: json
      });
    });

    document.title = "Auszüge" + " - " + constants.APP_TITLE;
  }


  componentWillUnmount(){
    if (document) {
      document.title = constants.APP_TITLE;
    }
  }


  renderAuszuege(zk_number){
    return this.state.auszuege[zk_number].map(function(auszug, i){

      const label = `Auszug ${parseInt(auszug)}`;

      const publicationDate = getPublicationDate(zk_number, auszug);

      return (
        <li key={i}>
          <Link
            to={
              "/bestand/zettelkasten/" + zk_number
              + "/auszug/" + parseInt(auszug)
            }
          >
            {label}
          </Link>
          <span style={{"whiteSpace": "pre"}}> </span>
          ({publicationDate})
          {
            (zk_number === 1 && parseInt(auszug) === 1)
            ? " ✔️"
            : ""
          }
          {
            (zk_number === 2 && parseInt(auszug) === 17)
            ? " (✔️)"
            : ""
          }
        </li>
      );
    });
  }


  render(){
    return (
      <DocumentPageFrame>
        <HTMLView src={"/assets/texts/bestände/ZK/auszugsuebersicht.html"}/>
        <p>
          ✔️ = transkribiert/ediert
          <span style={{"whiteSpace": "pre"}}>          </span>
          (✔️) = teilweise transkribiert/ediert
        </p>
        <div id="ZK_1">
          <h2>Zettelkasten I</h2>
          <ul>
            {this.state.auszuege ? this.renderAuszuege(1) : <BusySpinner/>}
          </ul>
        </div>
        <div id="ZK_2">
          <h2>Zettelkasten II</h2>
          <ul>
            {this.state.auszuege ? this.renderAuszuege(2) : <BusySpinner/>}
          </ul>
        </div>
      </DocumentPageFrame>
    );
  }
}
