import React from "react";

import { Link } from "react-router-dom";

import DocumentPageFrame from "../../../UI/DocumentPageFrame";
import Crumbs from "../../../UI/Crumbs";
import BusySpinner from "../../../UI/BusySpinner";
import HTMLView from "../../../UI/HTMLView";
import TextWithHighlightedTokens from "../../../UI/TextWithHighlightedTokens"
import TextField from '@material-ui/core/TextField';
import IconButton from '@material-ui/core/IconButton';
import InputAdornment from '@material-ui/core/InputAdornment';
import ClearIcon from '@material-ui/icons/Clear';

import { fetchJSON } from "../../../../utils.js";

const constants = require("../../../../constants.js");

export default class Inhaltsübersicht extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      ZK1_index: null,
      filterValue: ""
    };
  }


  componentDidMount(){
    const url = constants.URLS.ZK1_INDEX;

    fetchJSON(url)
    .then(json => {
      this.setState({
        ZK1_index: json
      });
    })
    .catch(e => {
      console.log("Error fetching " + url);
      console.log(e);
    });

    document.title = "Inhaltsübersicht ZK I"
    + " - " + constants.APP_TITLE;

  }


  componentWillUnmount(){
    if (document) {
      document.title = constants.APP_TITLE;
    }
  }


  renderInhaltsübersicht(root, zk_nummer){
    if (zk_nummer == "2"){
      return <p>Die Inhaltsübersicht des ZK II wurde noch nicht komplettiert.</p>
    }

    //We do not want the root node displayed,
    //so we render a tree for every child
    return <ul style={{"padding": "0"}}>
      {root.children.map(this.renderTree.bind(this))}
    </ul>
  }

  renderTree(root){

    const filterValue = this.state.filterValue;

    const linkTarget = root.target.substring(1);

    let label =
      root.n + " " + root.title
      + " (" + root.numberOfFrontPages + ")";

    if (root.isTranscribed){
      label = label + " ✔️";
    }

    let tokensToHighlight = [];
    if (filterValue.length > 2){
      tokensToHighlight = [filterValue];
    }

    return <li key={root.id} id={root.id} style={{"listStyleType": "none"}}>
      {
        label.toLowerCase().includes(filterValue.toLowerCase())
          ? <Link
            to={"/bestand/zettelkasten/zettel/" + linkTarget}
            title={root.zettel_title}
          >
            <TextWithHighlightedTokens
              text={label}
              tokensToHighlight={tokensToHighlight}
              highlightStyle={{fontWeight: 'bold', backgroundColor: "yellow"}}
            />
          </Link>
          : null
      }
      {root.children
        ? <ul>
          {
            root.children
            .filter(child => child.type !== "hole")
            .map(this.renderTree.bind(this))
          }
        </ul>
        : ""
      }
    </li>
  }


  render(){

    const self = this;
    const zk_nummer = this.props.zk_nummer;

    if (
      zk_nummer !== "1"
      && zk_nummer !== "2"
    ){
      return (<div>Diese Seite existiert nicht.</div>);
    }

    return (
      <DocumentPageFrame>
        <HTMLView src={"/assets/texts/bestände/ZK/inhaltsuebersicht.html"}/>
        <p>✔️ = transkribiert/ediert</p>
        <TextField
          id="standard-full-width"
          label="Suche in der Inhaltsübersicht"
          fullWidth
          margin="normal"
          value={this.state.filterValue}
          onChange={(e) => {
            this.setState({"filterValue": e.target.value});
          }}
          InputProps={{
            endAdornment: (
              <InputAdornment position="end">
                <IconButton
                  edge="end"
                  aria-label="Reset text"
                  onClick={() => this.setState({filterValue: ""})}
                >
                  <ClearIcon />
                </IconButton>
              </InputAdornment>
            ),
          }}
        />
        <h2>Zettelkasten I</h2>
        {
          this.state.ZK1_index
          ? this.renderInhaltsübersicht(
            this.state.ZK1_index,
            zk_nummer
          )
          : <BusySpinner/>
        }
      </DocumentPageFrame>
    );
  }
}
