import React from "react";
import TextWithHighlightedTokens from "../../../../UI/TextWithHighlightedTokens"

import { Link } from "react-router-dom";

const constants = require("../../../../../constants.js");

export default class Result extends React.Component {

  getResultText(result, tokensToHighlight = []){
    /*let maximumLength = 400;
    if (transcription.length > maximumLength){
      transcription = transcription.substring(0, maximumLength) + "...";
    }*/

    if (
      result.transcription.isTranscribed
      || (!process.env.NODE_ENV)
      || process.env.NODE_ENV === 'development'
    ){
      const transcription = result.transcriptionPreview;
      return <TextWithHighlightedTokens
        text={transcription}
        tokensToHighlight={tokensToHighlight}
        highlightStyle={{fontWeight: 'bold', backgroundColor: "yellow"}}
      />
    } else {
      return "Die Veröffentlichung der Transkription dieses Zettels ist noch nicht erfolgt.";
    }

  }


  render(){

    const result = this.props.result;
    let imageURL;
    if (result.isDummy){
      imageURL = "/assets/images/dummy_template_image.jpg";
    } else if (result.flags.hasCorrectedImage){
      imageURL = constants.URLS.CORRECTED_IMAGES_FOLDER + "jpg_thu/" + result.image.id + ".jpg";
    } else {
      imageURL = constants.URLS.IMAGE_API + result.image.id + "?size=0";
    }
    const logical_zk_number_roman = result.zk_number === "2" ? "II" : "I";

    return (
      <div style={{
        "display": "flex",
        "alignItems": "start",
        "marginBottom": "5px"
      }}>
        <Link
          to={constants.URLS.ZETTEL_URL_PREFIX + result.ekin}
          style={{
            "position": "relative"
          }}
        >
          <img
            style={{
              "margin": "10px",
              "marginTop": "0px",
              "maxWidth": "200px"
            }}
            src={imageURL}
          />
          {
            result.isDummy
            ? <p
              style={{
                "position": "absolute",
                "top": "50%",
                "left": "50%",
                "textAlign": "center",
                "transform": "translate(-50%, -50%)",
                "fontSize": "1.3rem",
                "lineHeight": "1.6rem",
                "color": "black"
              }}
            >
              Originalzettel liegt nicht vor
            </p>
            : ""
          }
        </Link>
        <div>
          <Link to={constants.URLS.ZETTEL_URL_PREFIX + result.ekin}>
            <h3 style={{"margin": "0px", "lineHeight": "1"}}>{
              (result.title === "")
              ? "Unbenannter Zettel (" + result.ekin + ")"
              : result.title
              }
            </h3>
          </Link>
          <p style={{"color": "green", "margin": "0", "fontWeight": "bold"}}>
            Zettelkasten: {logical_zk_number_roman}
            {", "}
            Auszug {result.file["dir-zettelkasten"]}/{result.file["dir-auszug"]}
          </p>
          <p>
            {this.getResultText(
              result,
              this.props.tokensToHighlight
            )}
          </p>
        </div>
      </div>
    );
  }
}
