import React from "react";
import { Link } from "react-router-dom";

const constants = require("../../../../../constants.js");

export default class DigitalisatBox extends React.Component {

  constructor(props) {
    super(props);
  }


  componentDidMount(){
    if (this.refs.canvas){
      const imageURLs = this.getImageURLs(this.props.zettel);
      const change = this.props.zettel.image.change;
      const change_digits_only = change.replace(/[^0-9]/g, '');
      const degrees = parseInt(change_digits_only);
      this.renderRotatedImageToCanvas(imageURLs.web, degrees);
    }
  }


  renderRotatedImageToCanvas(url, degrees){
    const canvas = this.refs.canvas;
    const img = new Image();
    img.src = url;

    img.onload = () => {

      if (degrees === 90 || degrees === 270){
        canvas.width = img.height;
        canvas.height = img.width;
      } else {
        canvas.width = img.width;
        canvas.height = img.height;
      }

      const ctx = canvas.getContext("2d");
      ctx.translate(canvas.width / 2, canvas.height / 2);
      ctx.rotate(degrees * Math.PI / 180);
      // since images draw from top-left offset the draw by 1/2 width & height
      ctx.drawImage(img, -img.width / 2, -img.height / 2);
      // un-rotate the canvas
      ctx.rotate(- degrees * Math.PI / 180);
      // un-translate the canvas back to origin==top-left canvas
      ctx.translate(-canvas.width / 2, -canvas.height / 2);
    }
  }


  getImageURLs(zettel){
    const image_urls = {};

    if (zettel.flags.hasCorrectedImage){
      image_urls.web = constants.URLS.CORRECTED_IMAGES_FOLDER + "jpg_web/" + zettel.image.id + ".jpg";
      image_urls.full_jpg = constants.URLS.CORRECTED_IMAGES_FOLDER + "jpg_full/" + zettel.image.id + ".jpg";
    } else {
      image_urls.web = constants.URLS.IMAGE_API + zettel.image.id + "?size=1";
      image_urls.full_jpg = constants.URLS.IMAGE_API + zettel.image.id + "?size=2";
    }

    return image_urls;
  }


  render(){

    let zettel = this.props.zettel;
    let image_urls = this.getImageURLs(zettel);

    let zettel_frame_content;
    if (zettel.availability == "restricted"){
      zettel_frame_content = "Der Inhalt dieser Zettelseite ist rechtlich \
      geschützt, und kann daher nicht angezeigt werden.";
    } else if (zettel.isDummy){
      zettel_frame_content = <div className="zettel_frame_content">
        <img src="/assets/images/dummy_template_image.jpg"/>
        <p className="zk_img_text_overlay">Originalzettel liegt nicht vor</p>
      </div>;
    } else if (zettel.image.id) {
      zettel_frame_content =
      <a href={image_urls.full_jpg}>
        {
          //Must image be rotated? then use some canvas magic
          !zettel.image.change.includes("rotate_0")
          ? <canvas ref="canvas"/>
          : <img src={image_urls.web} alt="Digitalisat des Zettels"/>
        }
      </a>;
    }

    return (
      <div className="zettel-digitalisat-div">
        {zettel_frame_content}
      </div>
    );
  }
}
