import React from "react";

import { Link } from "react-router-dom";

const constants = require("../../../../../constants.js");

import Button from '@material-ui/core/Button';

export default class DownloadBox extends React.Component {

  constructor(props) {
    super(props);
  }


  getButtons(zettel){

    const buttons = [
      {
        label: "JPG (optimiert)",
        href: (zettel) => constants.URLS.CORRECTED_IMAGES_FOLDER + "jpg_full/" + zettel.image.id + ".jpg",
        condition: (zettel) => ((typeof zettel == "object") && zettel.flags.hasCorrectedImage)
      },
      {
        label: "TIFF (optimiert)",
        href: (zettel) => constants.URLS.CORRECTED_IMAGES_FOLDER + zettel.image.id + ".tif",
        condition: zettel => ((typeof zettel == "object") && zettel.flags.hasCorrectedImage)
      },
      {
        label: zettel.flags.hasCorrectedImage ? "JPG (Original)" : "JPG",
        href: (zettel) => constants.URLS.IMAGE_API + zettel.image.id + "?size=2",
        condition: (zettel) => ((typeof zettel == "object") && !zettel.isDummy)
      },
      {
        label: zettel.flags.hasCorrectedImage ? "TIFF (Original)" : "TIFF",
        href: (zettel) => constants.URLS.IMAGE_API + zettel.image.id + "?size=3",
        condition: zettel => ((typeof zettel == "object") && !zettel.isDummy)
      },
      {
        label: "TEI-XML",
        href: (zettel) => {
          if (typeof zettel == "object" && zettel.file){
            return constants.URLS.DATABASE_API
              + "ZK/zettel/"
              + zettel.ekin
              + "/xml";
          }
        },
        condition: () => true
      },
      {
        label: "JSON",
        href: (zettel) => constants.URLS.DATABASE_API + "ZK/zettel/" + zettel.ekin,
        condition: () => true
      }
    ];

    return buttons
    .filter(b => b.condition(zettel))
    .map((b, i) => {
      return <a
        href={b.href(zettel)}
        key={i}
        className="buttonLink"
        style={{"margin": "5px"}}
      >
        <Button color="primary">
          {b.label}
        </Button>
      </a>;
    });

  }


  render(){
    return (
      <div className="zettel-downloads">
        <h5>Downloads</h5>
        {this.getButtons(this.props.zettel)}
      </div>
    );
  }
}
