import React from "react";

import { Link } from "react-router-dom";

import ShortNavButton from "./ShortNavButton";

const constants = require("../../../../../constants.js");

export default class NavigationMarkup extends React.Component {

  constructor(props) {
    super(props);
  }


  getCorrectedPhysicalNavigationRelations(zettel){
    return [
      {
        name: "Vorderseite-des-vorherigen-Zettels-in-corrected-physical-sequence",
        label: "Vorheriger Zettel im Kasten",
        icon: "arrow-left-bold-circle-outline",
        display: true,
        enabled: true
      },
      {
        name: "Vorderseite-des-naechsten-Zettels-in-corrected-physical-sequence",
        label: "Nächster Zettel im Kasten",
        icon: "arrow-right-bold-circle-outline",
        display: true,
        enabled: true
      },
      {
        name: "kehrseite",
        label: zettel ? (zettel.is_front ? "Rückseite" : "Vorderseite") : "Rückseite",
        icon: "flip-to-back",
        display: true,
        enabled: true
      }
    ];
  }


  getLogicalNavigationRelations(zettel){

    const isEnabled =
      (zettel && zettel.transcription.isTranscribed)
      || (process.env.PORTAL_MODE !== "production");


    let navData = zettel && zettel.navigation && zettel.navigation["logical"];

    const entryPointNavItem = navData && navData.find(
      navItem => navItem.relation === "Zum-Einstiegspunkt"
    );

    const displayToBeginningOfPreviousComplexButton =
      entryPointNavItem ? (entryPointNavItem.ekin === zettel.ekin) : true;

    const displayToBeginningOfThisComplexButton =
      entryPointNavItem ? (entryPointNavItem.ekin !== zettel.ekin) : false;

    return [
      {
        name: "Anfang-des-vorherigen-Komplexes",
        label: "Zum Einstiegspunkt des vorherigen Strangs",
        icon: "previous-complex",
        display: displayToBeginningOfPreviousComplexButton,
        enabled: isEnabled
      },
      {
        name: "Zum-Einstiegspunkt",
        label: "Zum Einstiegspunkt des aktuellen Strangs",
        icon: "previous-complex",
        display: displayToBeginningOfThisComplexButton,
        enabled: isEnabled
      },
      {
        name: "Anfang-des-naechsten-Komplexes",
        label: "Zum nächsten Einstiegspunkt",
        icon: "next-complex",
        display: true,
        enabled: isEnabled
      },
      {
        name: "rueckwaerts-in-diesem-Strang",
        label: "Rückwärts in diesem Strang",
        icon: "branch-backward",
        display: true,
        enabled: isEnabled
      },
      {
        name: "vorwaerts-in-diesem-Strang",
        label: "Vorwärts in diesem Strang",
        icon: "branch-forward",
        display: true,
        enabled: isEnabled
      },
      {
        name: "Anfang-des-Strangs",
        label: "Zum Anfang des Strangs",
        icon: "beginning_of_branch",
        display: true,
        enabled: isEnabled
      },
      {
        name: "vorwaerts-in-eingeschobenem-Strang",
        label: "Vorwärts in eingeschobenem Strang",
        icon: "einschub",
        display: true,
        enabled: isEnabled
      },
      {
        name: "vorwaerts-in-ergaenzendem-Strang",
        label: "Vorwärts in ergänzendem Strang",
        icon: "fork_from_here",
        display: true,
        enabled: isEnabled
      },
      {
        name: "vorwaerts-in-parallelem-Strang",
        label: "Vorwärts in parallelem Strang",
        icon: "parallel_branch",
        display: true,
        enabled: isEnabled
      },
      {
        name: "zurueck-zu-hoeherem-Strang",
        label: "Zum höheren Strang",
        icon: "origin_of_fork",
        display: true,
        enabled: isEnabled
      },
    ];
  }


  getNumericalNavigationRelations(zettel){

    const isEnabled =
      (zettel && zettel.transcription.isTranscribed)
      || (process.env.PORTAL_MODE !== "production");

    return [
      {
        name: "rueckwaerts-im-nummerierten-Gliederungsverlauf",
        label: "Rückwärts im nummerierten Gliederungsverlauf",
        icon: "numerical-branch-backward",
        display: true,
        enabled: isEnabled
      },
      {
        name: "vorwaerts-im-nummerierten-Gliederungsverlauf",
        label: "Vorwärts im nummerierten Gliederungsverlauf",
        icon: "numerical-branch-forward",
        display: true,
        enabled: isEnabled
      }
    ];
  }


  getRelationsOfNavType(navType, zettel){

    let relations;
    if (navType === "corrected_physical"){
      relations = this.getCorrectedPhysicalNavigationRelations(zettel);
    } else if (navType === "logical"){
      relations = this.getLogicalNavigationRelations(zettel);
    } else if (navType === "numerical"){
      relations = this.getNumericalNavigationRelations(zettel);
    }

    return relations.filter(r => r.display);

  }

  /*
    @param navType - string
    can be "corrected_physical", "logical", "numerical"

    @param zettel - zettel object
  */
  getMarkupOfNavType(navType, zettel){

    let navData = zettel && zettel.navigation && zettel.navigation[navType];
    if (!navData){
      navData = [];
    }

    const zettel_title = zettel && zettel.title;

    const markup = [];

    const relations = this.getRelationsOfNavType(navType, zettel);

    relations.forEach((relation, ri) => {

      const itemsOfRelation = navData.filter(
        x => (x.relation === relation.name)
      );

      if (itemsOfRelation.length === 0 || !relation.enabled){
        markup.push(
          <ShortNavButton
            id={"shortNav_" + relation.name}
            icon={relation.icon}
            relation={relation.label}
            targetLabel={null}
            disabled={true}
            zettel_title={zettel_title}
            key={"rel_" + ri + "_snb_disabled"}
          />
        );
      } else {
        itemsOfRelation.forEach(function(item, i){
          markup.push(
            <ShortNavButton
              id={"shortNav_" + i + "_" + relation.name}
              link={constants.URLS.ZETTEL_URL_PREFIX + item.ekin}
              icon={relation.icon}
              relation={relation.label}
              targetLabel={item.title}
              key={"rel_" + ri + "_snb_" + i}
            />
          );
        })
      }
    });

    return markup;

  }


  getMarkup(){
    return this.props.types.map((type, i, array) => {
      const markup = [];

      markup.push(
        <div className="nav-group" key={i}>
          {this.getMarkupOfNavType(
            type,
            this.props.zettel
          )}
        </div>
      );


      if (i < array.length - 1){
        markup.push(<div className="nav_separator" key={"ns_"+i}/>);
      }
      return markup;
    });
  }


  render(){
    return (
      <div className={"shortNav " + this.props.types.join(" ")}>
        {this.getMarkup()}
      </div>
    );
  }


}
