import React from "react";

import { Link } from "react-router-dom";

import TreeViewNode from "./TreeViewNode";
import BusySpinner from "../../../../../UI/BusySpinner";
import { fetchJSON } from "../../../../../../utils.js";
const constants = require("../../../../../../constants.js");

export default class InhaltsübersichtBox extends React.Component {

  constructor(props) {
    super(props);
  }


  componentDidUpdate(){
    this.scrollToActiveItem();
  }


  componentDidMount(){
    this.scrollToActiveItem();
  }


  scrollToActiveItem(){
    const container = this.refs.tree_container;
    if (!container){
      return;
    }
    const containerRect = container.getBoundingClientRect();
    const targetElement = document.getElementById(
      "iü_" + this.props.zettel.index.editor_I.substring(1)
    );

    if (!targetElement) return;

    // We need to reset the scroll position before we ask for the location of
    // the target element relative to the viewport.
    container.scrollTop = 0;
    const targetRect = targetElement.getBoundingClientRect();
    const offset = targetRect.top - containerRect.top;
    container.scrollTop = offset - 75;
    return;
  }


  getNode(treeNodes, searchID){
    for (let nodeIdx = 0; nodeIdx < treeNodes.length; nodeIdx++) {
      const currentNode = treeNodes[nodeIdx];
      const currentId = currentNode.id;
      const currentChildren = currentNode.children;

      if (currentId === searchID) {
        return currentNode;
      } else if (currentChildren) {
        const foundDescendant = this.getNode(currentChildren, searchID);
        if (foundDescendant){
          return foundDescendant;
        }
      }

    }
    return false;
  }


  getParent(tree, searchID){
    if (!tree || !tree.children || tree.children.length === 0) {
      return null;
    }

    if(tree.children){
      for (let i in tree.children) {
        if (tree.children[i].id === searchID) {
          return tree;
        }
        const res = this.getParent(tree.children[i], searchID);
        if (res) {
          return res;
        }
      }
      return null;
    } else {
      if (tree.children.id === searchID) {
        return tree;
      }
      return this.getParent(tree.children, searchID);
    }
  }


  render(){
    const treeRoot = this.props.ZK1_index;

    if (!treeRoot){
      return <BusySpinner/>
    }

    const term_id = this.props.zettel.index.editor_I.substring(1);
    const term = this.getNode([treeRoot], term_id);

    if (!term){
      console.error("cannot create index tree for term_id " + term_id);
      return <p style={{
        "padding": "10px"
      }}>
        Die Inhaltsübersicht kann bei diesem Zettel zur Zeit nicht angezeigt
        werden.
      </p>;
    }

    let parentNode = this.getParent(treeRoot, term_id);

    /*
      If the parent node, which is used as tree root, has the same entry zettel
      as the active node, use and display the grand-parent as tree root.
      Compare https://gitlab.ub.uni-bielefeld.de/luhmann/luhmann-react/issues/76
    */
    if (
      (parentNode.start_ekin === term.start_ekin)
      && (parentNode.id !== "root")
    ){
      parentNode = this.getParent(treeRoot, parentNode.id);
    }

    let treeNode = parentNode;

    return <div ref="tree_container" style={{
      "display": "grid",
      "maxHeight": "500px",
      "overflowY": "scroll",
      "padding": "10px"
    }}>
      {
        treeNode.title === "ZK I"
        ? treeNode.children.map(c => <TreeViewNode
            key={c.id}
            termIDToHighlight={term_id}
            treeNode={c}
          />
        )
        : <TreeViewNode
          key={treeNode.id}
          termIDToHighlight={term_id}
          treeNode={treeNode}
        />
      }
    </div>;
  }
}
