import React from "react";

import { Link } from "react-router-dom";

export default class TreeViewNode extends React.Component {

  getNodeLabel(treeNode, doCreateShortVersion){

    let label = "";

    if (treeNode.n){
      label += treeNode.n + " ";
    }

    label += treeNode.title;

    if (doCreateShortVersion && label.length > 80){
      label = label.substring(0, 80) + "...";
    }

    if (treeNode.numberOfFrontPages){
      label += " (" + treeNode.numberOfFrontPages + ")";
    }

    return label;

  }


  isActiveNodeDescendantOrSelf(treeNode, termIDToHighlight){
    if (treeNode.id === termIDToHighlight) return true;

    let pos = treeNode.children
    .filter(c => c.type !== "hole")
    .findIndex(n => {
      return (
        n.id === termIDToHighlight
        || this.isActiveNodeDescendantOrSelf(n, termIDToHighlight)
      );
    });

    return pos > -1;
  }


  constructParentNode(treeNode, termIDToHighlight){
    return (
      <li key={treeNode.id} className="" style={{"listStyleType": "none"}}>
        <details open={
          this.isActiveNodeDescendantOrSelf(treeNode, termIDToHighlight)
        }>
          <summary>
            {this.getLinkForTreeNode(treeNode, termIDToHighlight)}
          </summary>
          <ul style={{
            "listStyleType": "none",
            "paddingLeft": "17px",
            "margin": "0px",
            "lineHeight": "20px"
          }}>
            {
              treeNode.children
              && (treeNode.children.filter(c => c.type !== "hole").length > 0)
              && treeNode.children
              .filter(child => child.type !== "hole")
              .map(child => {
                return this.constructNode(child, termIDToHighlight);
              })
            }
          </ul>
        </details>
      </li>
    );
  }


  constructNode(treeNode, termIDToHighlight){
    if (
      treeNode.children
      && (treeNode.children.filter(c => c.type !== "hole").length > 0)
    ){
      return this.constructParentNode(treeNode, termIDToHighlight)
    } else {
      let link = this.getLinkForTreeNode(treeNode, termIDToHighlight, true);
      return (
        <li className="" key={treeNode.id} style={{
          "listStyleType": "none",
          "lineHeight": "20px"
        }}>
          {link}
        </li>
      );
    }
  }


  getLinkForTreeNode(treeNode, termIDToHighlight, doIndent){
    let label = this.getNodeLabel(treeNode);
    let shortLabel = this.getNodeLabel(treeNode, true);
    let isHighlighted = termIDToHighlight === treeNode.id;

    return (
      <div id={"iü_" + treeNode.id} style={{
        "display": "inline-block",
        "width": "92%",
        "verticalAlign": "top",
        "marginLeft": doIndent ? "15px" : "0px",
        "backgroundColor": isHighlighted ? "lightskyblue" : "",
        "borderRadius": "3px",
        "marginBottom": "5px"
      }}>
        <Link
          to={treeNode.target.substring(1)}
          style={{"textDecoration": "none"}}
          title={treeNode.zettel_title}
          className="iü_link"
        >
          <span style={{
            "textTransform": "none",
            "fontWeight": "400",
            "color": "black"
          }}>
            {shortLabel}
          </span>
        </Link>
      </div>
    );
  }


  render(){
    let treeNode = this.props.treeNode;
    let termIDToHighlight = this.props.termIDToHighlight;
    return this.constructNode(treeNode, termIDToHighlight);
  }
}
