import React from "react";

import { Link } from "react-router-dom";
import { fetchJSON } from "../../../../../utils.js";
import { withRouter } from 'react-router'

import BusySpinner from "../../../../UI/BusySpinner";

import Sidebar from "./Sidebar/";
import NavBar from "./NavBar";
import TitleBox from "./TitleBox";
import DigitalisatBox from "./DigitalisatBox";
import TranskriptionBox from "./TranskriptionBox";
import BranchViewBox from "./BranchViewBox";
import Metadata from "./Metadata";
import AnmerkungenBox from "./AnmerkungenBox";
import DownloadBox from "./DownloadBox";
import Error from "./Error";

const constants = require("../../../../../constants.js");

class Zettel extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      zettel: null,
      isLoading: false,
      ZK1_index: null
    };
  }


  componentDidUpdate(prevProps){
    const ekin = this.props.match.params.ekin;
    if (prevProps.match.params.ekin !== ekin){
      this.fetchData(ekin);
    }
  }


  componentDidMount() {
    this.fetchData(this.props.match.params.ekin);
    this.fetchIndex();
  }


  componentWillUnmount(){
    if (document) {
      document.title = constants.APP_TITLE;
    }
  }


  fetchIndex(){
    const url = constants.URLS.ZK1_INDEX;

    fetchJSON(url)
    .then(json => {
      this.setState({
        ZK1_index: json
      });
    })
    .catch(e => {
      console.log("Error fetching " + url);
      console.log(e);
    });

  }


  fetchData(ekin) {

    var self = this;

    if (!ekin){
      self.setState({
        error: "unknownEKIN"
      });
      return;
    }

    const url = constants.URLS.DATABASE_API
    + "ZK/zettel/" + ekin;

    self.setState({
      isLoading: true,
      zettel: null,
      error: null
    });

    fetchJSON(url)
    .then(function(json){

      if (json.error){
        self.setState({
          error: "unknownEKIN",
          isLoading: false
        });
        return;
      }

      self.setState({
        zettel: json,
        error: null,
        isLoading: false
      });

      if (document) {
        document.title =
        (self.state.zettel.title || self.state.zettel.ekin)
        + " - "
        + constants.APP_TITLE;
      }

    })
    .catch(e => {
      self.setState({
        error: "server",
        isLoading: false
      });
      console.log(e);
    });

    return;

  }


  render(){

    if (this.state.error){
      return <Error
        error={this.state.error}
        ekin={this.props.match.params.ekin || ""}
      />;
    } else if (this.state.isLoading){
      const zettel = this.state.zettel;
      const ZK1_index = this.state.ZK1_index;
      return (
        <div className="zettel-page-wrapper">
          <Sidebar zettel={zettel} ZK1_index={ZK1_index}/>
          <NavBar zettel={zettel}/>
          <h3 className="zettel-title">
            <BusySpinner/>
          </h3>
        </div>
      );
    } else if (this.state.zettel){
      const zettel = this.state.zettel;
      const ZK1_index = this.state.ZK1_index;
      return (
        <div className="zettel-page-wrapper editorialContent">
          <Sidebar zettel={zettel} ZK1_index={ZK1_index} />
          <NavBar zettel={zettel}/>
          <TitleBox zettel={zettel}/>
          <DigitalisatBox zettel={zettel} />
          <TranskriptionBox zettel={zettel} />
          <BranchViewBox zettel={zettel} />
          <AnmerkungenBox zettel={zettel} />
          <Metadata zettel={zettel} ZK1_index={ZK1_index} />
          <DownloadBox zettel={zettel} />
        </div>
      );
    } else {
      return "";
    }


  }
}

export default withRouter(Zettel)
