import React from "react";
import { Link } from "react-router-dom";

import DocumentPageFrame from "../../../UI/DocumentPageFrame";
import BestandBar from "../../../UI/BestandBar";
import FullPageFrame from "../../../UI/FullPageFrame";

const constants = require("../../../../constants.js");

import { Route } from "react-router-dom";

import Inhaltsübersicht from "./Inhaltsübersicht"
import Zettelsuche from "./Search"
import Auszüge from "./Auszüge"
import Tutorial from "./Tutorial"

import Button from '@material-ui/core/Button';
import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';
import Typography from '@material-ui/core/Typography';
import withWidth from '@material-ui/core/withWidth';

function TabContainer(props) {
  return (
    <Typography component="div" style={{ padding: 8 * 3 }}>
      {props.children}
    </Typography>
  );
}

const SUBPAGES = [
  {
    "name": "suche",
    "label": "Zettelsuche",
    "link": "/bestand/zettelkasten/suche"
  },
  {
    "name": "inhaltsuebersicht",
    "label": "Inhaltsübersicht",
    "link": "/bestand/zettelkasten/inhaltsuebersicht"
  },
  {
    "name": "auszuege",
    "label": "Auszugsübersicht",
    "link": "/bestand/zettelkasten/auszuege"
  },
  {
    "name": "schlagwortregister",
    "label": "Schlagwortregister",
    "disabled": true
  },
  {
    "name": "personenregister",
    "label": "Personenregister",
    "disabled": true
  },
  {
    "name": "bibliographie",
    "label": "Bibliographie",
    "disabled": true
  },
  {
    "name": "tutorial",
    "label": "Tutorial",
    "link": "/bestand/zettelkasten/tutorial"
  }
]

class Zettelkasten extends React.Component {

  constructor(props) {
    super(props);
    this.state = {};
  }

  handleSubpageChange(activeSubpageIndex){
    const subpageURL = SUBPAGES[activeSubpageIndex].link;
    const location = {...this.props.history.location};
    location.pathname = subpageURL;
    this.props.history.push(location);
  }

  handleClickOnRandomZettelButton() {
    const location = {...this.props.history.location};
    location.pathname = "/bestand/zettelkasten/random";
    this.props.history.push(location);
  }

  render(){
    const subpageName = this.props.match.params.subpage;
    const activeSubpageIndex = SUBPAGES.findIndex(
      obj => obj.name === subpageName
    );

    const width = this.props.width;
    const isSmallScreen = width === "xs";

    return (
      <FullPageFrame>
        <BestandBar>
          <Tabs
            value={activeSubpageIndex}
            onChange={(e, activeSubpageIndex) => this.handleSubpageChange(
              activeSubpageIndex
            )}
            indicatorColor="primary"
            textColor="primary"
            centered={!isSmallScreen}
            variant={isSmallScreen ? "scrollable" : "standard"}
            scrollButtons={isSmallScreen ? "on" : "off"}
          >
            {
              SUBPAGES.map(p =>
                <Tab
                  label={p.label}
                  disabled={p.disabled}
                  key={"tab_" + p.name}
                />
              )
            }
          </Tabs>
{/*
          <div style={{"padding": "0px 30px"}}>
            <Button
              onClick={() => this.handleClickOnRandomZettelButton()}
              variant="outlined"
              color="primary"
            >
              Zufälliger Zettel
            </Button>
          </div>
*/}
        </BestandBar>

        <Route path="/bestand/zettelkasten/suche"
          exact
          component={Zettelsuche}
        />
        <Route path="/bestand/zettelkasten/tutorial"
          exact
          component={Tutorial}
        />
        <Route path="/bestand/zettelkasten/auszuege"
          exact
          component={Auszüge}
        />
        <Route path="/bestand/zettelkasten/inhaltsuebersicht"
          exact
          render={() => <Inhaltsübersicht zk_nummer={"1"}/>}
        />
      </FullPageFrame>
    );
  }
}

export default withWidth()(Zettelkasten);
