import React from "react";
import { Link } from "react-router-dom";
import { fetchJSON } from "../../../../utils.js";

import DocumentPageFrame from "../../../UI/DocumentPageFrame";
import Crumbs from "../../../UI/Crumbs";
import BusySpinner from "../../../UI/BusySpinner";
import TeamMember from "./TeamMember";

const constants = require("../../../../constants.js");

const formerHelpers = [
  "Leo Bitter",
  "Jascha Nord",
  "Luca Jana Sophie Sonnen",
  "Emil Weinig",
  "Marilena Buchholz",
  "Marie Sauer",
  "Dana Persch"
];

export default class Team extends React.Component {

  constructor(props) {
    super(props);
  }


  renderMarkup() {

    const data = [
      {
        "institution": "Fakultät für Soziologie, Universität Bielefeld",
        "members": [
          {
            "name": "Prof. Dr. André Kieserling",
            "role": "Projektleiter",
            "mail": "andre.kieserling@uni-bielefeld.de",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "Andre-Kieserling-quad-500.jpg"
          },
          {
            "name": "Dipl.-Soz. Johannes Schmidt",
            "mail": "johannes.schmidt@uni-bielefeld.de",
            "role": "Wissenschaftlicher Projektkoordinator",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "johannes-schmidt-quad-500.jpg",
            "function": "Editionskonzeption, Schlussredaktion, Edition des Zettelkastens (Inhaltsübersicht)"
          },
          {
            "name": "Dipl.-Soz. Christoph Gesigora",
            "mail": "christoph.gesigora@uni-bielefeld.de",
            "role": "Wissenschaftlicher Mitarbeiter",
            "function": "Bestandserfassung, Edition der Manuskripte, Redaktion Zettelkasten",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "Portalphoto_CG_quad-500.jpg"
          },
          {
            "name": "Kristoffer Klement, M.A.",
            "mail": "kristoffer.klement@uni-bielefeld.de",
            "role": "Wissenschaftlicher Mitarbeiter",
            "function": "Edition des Zettelkastens",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "Portalphoto_KK_quad-500.jpg"
          },
          {
            "name": "André Siekmeier, M.A.",
            "mail": "a.siekmeier@uni-bielefeld.de",
            "role": "Wissenschaftlicher Mitarbeiter",
            "function": "Edition des Zettelkastens",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "Portalphoto_AS_quad-500.jpg"
          },
          {
            "name": "Babak Khoshroo, B.A.",
            "mail": "babak.khoshroo@uni-bielefeld.de",
            "role": "Wissenschaftliche Hilfskraft",
            "function": "Bestandserfassung der Manuskripte",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "Portalphoto_BK_quad-500.jpg"
          },
          {
            "name": "Tobias Dreier, B.A.",
            "mail": "tobias.dreier@uni-bielefeld.de",
            "role": "Wissenschaftliche Hilfskraft",
            "function": "Gesamtbibliographie Luhmanns",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "Portalphoto_TD_quad-500.jpg"
          },
          {
            "name": "Youssef Ibrahim, M.A.",
            "mail": "youssef.ibrahim@uni-bielefeld.de",
            "role": "Wissenschaftliche Hilfskraft",
            "function": "Bibliographie des Zettelkastens / Gesamtbibliographie Luhmanns",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "Portalphoto_YI_quad-500.jpg"
          },
          {
            "name": "Prof. Dr. Rudolf Stichweh",
            "subtitle": "Dahrendorf Professur \"Theorie der modernen Gesellschaft\", Forum Internationale Wissenschaft, Universität Bonn",
            "link": "https://www.fiw.uni-bonn.de/demokratieforschung/personen/stichweh/prof.-dr.-rudolf-stichweh",
            "role": "Externer Kooperationspartner"
          },
        ],
        "formerMembers": [
          {
            "name": "Dr. Daniel Kinitz",
            "role": "Bibliographie"
          }
        ]
      },
      {
        "institution": "Cologne Center for eHumanities, Universität zu Köln",
        "members": [
          {
            "name": "Prof. Dr. Patrick Sahle",
            "subtitle": "Bergische Universität Wuppertal",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "patrick-sahle-quad-300.jpg",
            "mail": "sahle@uni-wuppertal.de",
            "role": "Koordination Digital Humanities"
          },
          {
            "name": "Martina Gödel",
            "img": "http://cceh.uni-koeln.de/files/martina2_web.JPG",
            "mail": "mgoedel@uni-koeln.de",
            "role": "Wissenschaftliche Mitarbeiterin",
            "function": "TEI-Datenmodelle (Zettelkasten/Manuskripte/Bibliographien/Register), Begleitung der editorischen Arbeiten"
          },
          {
            "name": "Sebastian Zimmer, M.A.",
            "img": "http://cceh.uni-koeln.de/files/sebastian_zimmer-klein.jpg",
            "mail": "sebastian.zimmer@uni-koeln.de",
            "role": "Wissenschaftlicher Mitarbeiter",
            "function": "Backend-/Frontend-Entwicklung, Technische Infrastruktur, Visualisierungen"
          }
        ]
      },
      {
        "institution": "Universitätsarchiv, Universität Bielefeld",
        "members": [
          {
            "name": "Rüdiger Buchholtz, M.A.",
            "mail": "ruediger.buchholtz@uni-bielefeld.de",
            "role": "Archivar",
            "function": "Archivarische Bestandserschließung"
          },
          {
            "name": "Sonja Beinlich",
            "mail": "sonja.beinlich@uni-bielefeld.de",
            "img": constants.URLS.ASSET_SERVER_STATIC_IMAGES + "Sonja-Beinlich-quad-500.jpg",
            "role": "Wissenschaftliche Hilfskraft",
            "function": "Archivarische Bestandserschließung"
          }
        ]
      },
      {
        "institution": "Universitätsbibliothek, Universität Bielefeld",
        "members": [
          {
            "name": "Artur Nold",
            "mail": "artur.nold@uni-bielefeld.de",
            "function": "Aufbereitung & Bereitstellung der Digitalen Sammlung"
          },
          {
            "name": "Ralf Hofacker",
            "mail": "ralf.hofacker@uni-bielefeld.de",
            "function": "Zettelkasten (Digitale Sammlung)"
          }
        ]
      }
    ];


    return data.map((institution, i) => {
      const markup = [];

      markup.push(<h2 key={"institution_" + i}>{institution.institution}</h2>);
      const members = institution.members.map((member, j) => {
        return <TeamMember data={member} key={"institution_member_" + i + "_" + j} />
      })
      markup.push(members);

      if (institution.formerMembers){
        markup.push(
          <h3 key={"institution_" + i + "formerMembersHeading"}>
            Ehemalige Mitarbeiter
          </h3>
        );
        const formerMembers = institution.formerMembers.map((member, j) => {
          return <TeamMember
            data={member}
            key={"institution_formerMember_" + i + "_" + j}
          />;
        });
        markup.push(formerMembers);
      }

      return markup;
    });
  }

  render(){

    const self = this;

    return (
      <DocumentPageFrame>
        <h1>Team</h1>
        {this.renderMarkup()}
        <h2>Ehemalige Hilfskräfte und Praktikanten</h2>
        {
          formerHelpers.map((helper, j) => {
            return <li key={"formerHelper_" + j}>
              {helper}
            </li>
          })
        }
      </DocumentPageFrame>
    );
  }
}
