import React from "react";
import { Link } from "react-router-dom";
import { fetchJSON } from "../../../utils.js";

import DocumentPageFrame from "../../UI/DocumentPageFrame";
import Crumbs from "../../UI/Crumbs";
import HTMLView from "../../UI/HTMLView";

import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';

import { Route } from "react-router-dom";

import Team from "./Team";
import Publikationen from "./Publikationen";
import Beschreibung from "./Beschreibung";
import Dokumentation from "./Dokumentation";
import Vorträge from "./Vorträge";

const constants = require("../../../constants.js");


const TABS = [
  {
    "name": "beschreibung",
    "label": "projektbeschreibung",
    "link": "/projekt/beschreibung"
  },
  {
    "name": "publikationen",
    "label": "Publikationen",
    "link": "/projekt/publikationen"
  },
  {
    "name": "vortraege-interviews",
    "label": "Vorträge/Interviews",
    "link": "/projekt/vortraege-interviews"
  },
  {
    "name": "dokumentation",
    "label": "Dokumentation",
    "link": "/projekt/dokumentation"
  },
  {
    "name": "team",
    "label": "Team",
    "link": "/projekt/team"
  },
];


export default class Projekt extends React.Component {

  constructor(props) {
    super(props);
    this.state = {};
  }


  handleMainChange(event, activeTabIndex){
    const link = TABS[activeTabIndex].link;
    this.props.history.push(link);
  }



  render(){
    const self = this;
    const activeTabName = this.props.match.params.tab;
    const activeTabIndex = TABS.findIndex(
      obj => obj.name === activeTabName
    );

    const width = this.props.width;
    const isSmallScreen = width === "xs";

      return (
        <div>
          <div className="mainSelect" style={{
            "background": "#607d8b66",
            "color": "#485e69"
          }}>
            <Tabs
              value={activeTabIndex}
              onChange={this.handleMainChange.bind(this)}
              centered={!isSmallScreen}
              variant={isSmallScreen ? "scrollable" : "standard"}
              scrollButtons={isSmallScreen ? "on" : "off"}
              indicatorColor="primary"
            >
              {
                TABS
                .map(b =>
                  <Tab
                    label={b.label}
                    disabled={b.disabled}
                    key={"b-tab-" + b.name}
                  />
                )
              }
            </Tabs>
          </div>
          <Route path="/projekt/beschreibung"
            component={Beschreibung}
          />
          <Route exact path="/projekt/publikationen"
            component={Publikationen}
          />
          <Route exact path="/projekt/vortraege-interviews"
            component={Vorträge}
          />
          <Route exact path="/projekt/dokumentation"
            component={Dokumentation}
          />
          <Route exact path="/projekt/team"
            component={Team}
          />
        </div>
    );
  }
}
