const cloneObject = (obj) => {
  let clone = {};

  if (Array.isArray(obj)){
    clone = [];
  }

  for (let i in obj) {
    if (obj[i] && typeof obj[i] == 'object') {
      clone[i] = cloneObject(obj[i]);
    } else {
      clone[i] = obj[i];
    }
  }

  return clone;
}


const sortByKey = (array, key) => {
  return array.sort(function(a, b) {
    let x = a[key];
    let y = b[key];

    if (typeof x == "string"){
      x = x.toLowerCase();
      y = y.toLowerCase();
    }

    return ((x < y) ? -1 : ((x > y) ? 1 : 0));
  });
}


const fetchJSON = (url, options) => {
  return fetch(url, options).then(r => r.json());
}


// Simple checksum generator taken from
// https://stackoverflow.com/a/3276730/3890888
const createChecksum = (s) => {
  var chk = 0x12345678;
  var len = s.length;
  for (var i = 0; i < len; i++) {
      chk += (s.charCodeAt(i) * (i + 1));
  }

  return (chk & 0xffffffff).toString(16);
}


const groupByKey = (allItems, groupingKey) => {
  return allItems.reduce(function (objectWithGroupedItems, item) {
    //Create array if not already there
    objectWithGroupedItems[item[groupingKey]] =
      objectWithGroupedItems[item[groupingKey]] || [];
    //Push item into correct array
    objectWithGroupedItems[item[groupingKey]].push(item);
    return objectWithGroupedItems;
  }, Object.create(null));
};


module.exports = {
  cloneObject,
  sortByKey,
  fetchJSON,
  createChecksum,
  groupByKey
}
