const express = require('express');
const app = express();
const React = require('react');
import ReactDOMServer from 'react-dom/server'
const fs = require("fs");
const path = require("path");
const compression = require('compression');
import ServerRootComponent from "./app/components/ServerRootComponent.js";
import { ServerStyleSheets } from '@material-ui/styles';

console.log("React version: " + React.version);

//Load robots.txt
const robotsTxt = fs.readFileSync(
  path.resolve(__dirname, "robots.txt"),
  "utf8"
);

// GZIP all assets
app.use(compression());

const init = (config) => {

  const indexHtml = fs.readFileSync(
    path.resolve(__dirname, "index.html"),
    "utf8"
  );

  express.static.mime.define({'application/xml': ['xml', 'odd', 'rng']});
  app.use('/assets', express.static(__dirname + '/assets'));

  app.get('/robots.txt', function(request, response) {
    response.type("txt");
    response.send(robotsTxt);
  });

  app.get('*', function(request, response) {

    const sheets = new ServerStyleSheets();

    const appHtml = ReactDOMServer.renderToString(
      sheets.collect(
        <ServerRootComponent
          location={request.url}
        />
      )
    );

    const css = sheets.toString();

    const html = indexHtml
    .replace(
      '<div id="app">',
      '<div id="app">' + appHtml
    )
    .replace(
      '<div id="app">',
      '<style id="jss-server-side">' + css + '</style><div id="app">'
    );

    response.send(html);
  });

  app.listen(config.port, function() {
    console.log('Listening to http://localhost:' + config.port);
  });

}

module.exports = {
  init
};
